@@ -156,10 +156,12 @@ on_help_about_activate (GtkAction *action,
                                "documenters", documenters,
                                "version", VERSION,
                                "copyright", "Copyright \xc2\xa9 2003-2007 William Jon McCann, Eric Farmer",
-                               "comments", _("Blackjack is a casino-style card game."),
+                               "comments", _("Blackjack is a casino-style card game.\n\n"
+			       "Blackjack is a part of GNOME Games."),
                                "logo-icon-name", "gnome-blackjack",
                                "license", license,
-                               "translator_credits", _("translator-credits"),
+			       "website-label", _("GNOME Games web site"),
+                               "translator-credits", _("translator-credits"),
                                "website", "http://www.gnome.org/projects/gnome-games/",
                                "wrap-license", TRUE,
                                NULL);
