@@ -13,12 +13,6 @@ import sys
 import time
 from gettext import gettext as _
 
-try:
-    import pygtk
-    pygtk.require('2.0')
-except ImportError, err:
-    print ("PyGTK not found. Please make sure it is installed properly and referenced in your PYTHONPATH environment variable.")
-
 import gobject
 import gtk
 import gtk.glade
@@ -53,8 +47,6 @@ class GtkGameNotebook(gtk.Notebook):
     """
     """
     
-    glConfig          = None
-
     defaultView       = None
     views             = None
     viewsByWidget     = None
@@ -72,19 +64,6 @@ class GtkGameNotebook(gtk.Notebook):
         # Make the tabs scrollable so the area is not resized
         self.set_scrollable(True)
         
-        # Configure openGL
-        try:
-            gtk.gdkgl
-        except AttributeError:
-            self.glConfig = None
-        else:
-            display_mode = (gtk.gdkgl.MODE_RGB | gtk.gdkgl.MODE_DEPTH | gtk.gdkgl.MODE_DOUBLE)
-            try:
-                self.glConfig = gtk.gdkgl.Config(mode = display_mode)
-            except gtk.gdkgl.NoMatches:
-                display_mode &= ~gtk.gdkgl.MODE_DOUBLE
-                self.glConfig = gtk.gdkgl.Config(mode = display_mode)
-            
         self.set_show_tabs(False)
         
     def setDefault(self, feedback):
@@ -396,6 +375,9 @@ class GtkUI(glchess.ui.UI):
         self._gui = loadGladeFile('glchess.glade')
         self._gui.signal_autoconnect(self)
         
+        # Workaround as Glade 2 always overrides the system style for toolbars
+        self.__getWidget('toolbar').unset_style()
+        
         # Create mappings between the promotion radio buttons and the promotion types
         self.__promotionTypeByRadio = {}
         self.__promotionRadioByType = {}
